@@ -56,6 +56,7 @@ class CategoricalStats:
         else:
             dim = math.ceil(math.sqrt(len(top_n)))
             num_rows = math.ceil(num_plots / dim)
+            plt.figure(figsize=(18, 14))
             fig, ax = plt.subplots(num_rows, dim)
             fig.tight_layout()
             fig.suptitle("Top 5 Value Counts and Percentages for Each Feature")
@@ -71,7 +72,6 @@ class CategoricalStats:
                 ax1_i = ax_i
                 ax1_i.bar(count_data.iloc[:, 0], count_data.iloc[:, 1].to_list(), color='gray')
                 ax2_i = ax1_i.twinx()
-                print(percent_data)
                 ax2_i.plot(percent_data.iloc[:, 0], percent_data.iloc[:, 1].to_list(), color='red', marker='o')
                 ax1_i.set_ylabel('Counts', color='gray')
                 ax2_i.set_ylabel('Percentages', color='red')
